==> haskell-interpolatedstring-perl6-1.0.1-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolatedstring-perl6
version: 1.0.1
id: interpolatedstring-perl6-1.0.1-EmDHzi5K1iFGjGEs0WvWpZ
key: interpolatedstring-perl6-1.0.1-EmDHzi5K1iFGjGEs0WvWpZ
license: LicenseRef-PublicDomain
copyright: Audrey Tang
maintainer: Audrey Tang <audreyt@audreyt.org>
author: Audrey Tang
stability: stable
synopsis: QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.
category: Data
abi: 1dd1094d081729de8f0bee3d1b0cbebd
exposed: True
exposed-modules:
    Text.InterpolatedString.Perl6
import-dirs: /usr/lib/ghc-8.6.4/site-local/interpolatedstring-perl6-1.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/interpolatedstring-perl6-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-interpolatedstring-perl6
hs-libraries: HSinterpolatedstring-perl6-1.0.1-EmDHzi5K1iFGjGEs0WvWpZ
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    haskell-src-meta-0.8.2-INJHEC4oQl0L8dztRsQnMu
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock
haddock-html: /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolatedstring-perl6-1.0.1-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolatedstring-perl6
version: 1.0.1
id: interpolatedstring-perl6-1.0.1-76XBDyNGvqQEgPodsoj2Cw
key: interpolatedstring-perl6-1.0.1-76XBDyNGvqQEgPodsoj2Cw
license: LicenseRef-PublicDomain
copyright: Audrey Tang
maintainer: Audrey Tang <audreyt@audreyt.org>
author: Audrey Tang
stability: stable
synopsis: QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.
category: Data
abi: 3b378f948a7e5a57131128cc5740b00c
exposed: True
exposed-modules:
    Text.InterpolatedString.Perl6
import-dirs: /usr/lib/ghc-8.6.4/site-local/interpolatedstring-perl6-1.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/interpolatedstring-perl6-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-interpolatedstring-perl6
hs-libraries: HSinterpolatedstring-perl6-1.0.1-76XBDyNGvqQEgPodsoj2Cw
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    haskell-src-meta-0.8.2-FDpMRx1FcXa5zE4mFJzom5
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock
haddock-html: /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
